import matplotlib.pyplot as plt
import numpy as np





def get_reference(do_plot=False):
    with open('ex.txt', 'r') as f:
        s = f.read()
    x = [int(a) for a in s[34:-4].split(',')]
    if do_plot:
        plt.close()
        plt.plot(x)
        plt.show()
    return x


def make_sine(f, fs, NT, phi):
    """Generate a sinusoidal signal.

    The signal has integer valus, mean value 110, and amplitude 100.

    Parameters
    ----------
    f : float
        Frequency of the sinusoid in Hz.
    fs : float
        Sampling frequency in Hz.
    NT : int
        Number of periods of the sinusoid.
    phi : float
        Phase of the sinusoid in radians.

    Returns
    -------
    numpy.ndarray
        An integer NumPy array representing the generated sinusoidal signal.
    """
    A = 100
    offset = 110
    twopi = 2 * np.pi
    phi = phi % twopi
    tmax = (NT + (phi / twopi)) / f
    t = np.arange(0, tmax, 1/fs)
    x = A * np.sin(2 * np.pi * f * t) + offset
    x = x.astype(int)
    return t, x

if __name__=='__main__':
    # f = 10.1  # Frequency of the sinusoid in Hz
    f = 10  # Frequency of the sinusoid in Hz
    fs = 1000  # Sampling frequency in Hz
    # NT = 5  # Number of periods
    NT = 50  # Number of periods
    phi = np.pi # Phase in radian
    t, x = make_sine(f, fs, NT, phi)
    xl = ', '.join(x.astype(str))
    s = f'const int sinTable_value []={{{xl}}};\n'

    fn = 'sine_table.h'
    with open(fn, 'w') as file:
        file.write(s)
    print(f'Sine table written into {fn}')

    # xr = get_reference()

    plt.close('all')
    plt.plot(t, x)
    plt.grid()
    plt.show()
